@@ -25,6 +25,11 @@ class CordException(Exception):
         return self.message
 
 
+class InitialisationError(CordException):
+    """ Exception thrown when API key fails to initialise. """
+    pass
+
+
 class AuthenticationError(CordException):
     """ Exception thrown when API key fails authentication. """
     pass
@@ -98,6 +103,11 @@ class FileTypeNotSupportedError(CordException):
     pass
 
 
+class UploadOperationNotSupportedError(CordException):
+    """ Exception thrown when trying to upload a video/image group to non-Cord storage dataset """
+    pass
+
+
 class DetectionRangeInvalidError(CordException):
     """
     Exception thrown when a detection range is invalid.
